aboutsummaryrefslogtreecommitdiffstats
path: root/addressbook/backend/ebook/e-card.h
diff options
context:
space:
mode:
Diffstat (limited to 'addressbook/backend/ebook/e-card.h')
-rw-r--r--addressbook/backend/ebook/e-card.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/addressbook/backend/ebook/e-card.h b/addressbook/backend/ebook/e-card.h
index e70b3337c2..15a5ca74c7 100644
--- a/addressbook/backend/ebook/e-card.h
+++ b/addressbook/backend/ebook/e-card.h
@@ -48,9 +48,14 @@ struct _ECard {
char *org; /* The person's organization. */
- char *role; /* The person's role w/in his ord */
+ char *org_unit; /* The person's organization unit. */
+ char *role; /* The person's role w/in his org */
char *title; /* The person's title w/in his org */
+ char *nickname; /* The person's nickname */
+
+ char *fburl; /* Free Busy URL */
+
#if 0
ECardOrg *org; /* The person's organization. */